@@ -5,6 +5,7 @@
 #include "_png.h"
 #include "_jpeg.h"
 #include "_tiff.h"
+#include "_webp.h"
 
 #include <cstring>
 
@@ -13,5 +14,7 @@ std::auto_ptr<ImageFormat> get_format(const char* format) {
     if (!strcmp(format, "png")) return std::auto_ptr<ImageFormat>(new PNGFormat);
     if (!strcmp(format, "jpeg") || !strcmp(format, "jpg")) return std::auto_ptr<ImageFormat>(new JPEGFormat);
     if (!strcmp(format, "tiff") || !strcmp(format, "tif")) return std::auto_ptr<ImageFormat>(new TIFFFormat);
+    if (!strcmp(format, "webp")) return std::auto_ptr<ImageFormat>(new WebPFormat);
+    if (!strcmp(format, "stk")) return std::auto_ptr<ImageFormat>(new STKFormat);
     return std::auto_ptr<ImageFormat>(0);
 }
